Project Structure
=================

.. code-block:: text

    └── JAX-in-Cell/
        ├── LICENSE
        ├── docs
        ├── examples
        │   ├── Landau_damping.py
        │   ├── Langmuir_wave.py
        │   ├── ion-acoustic_wave.py
        │   ├── two-stream_instability.py
        │   ├── auto-differentiability.py
        │   ├── scaling_energy_time.py
        │   └── optimize_two_stream_saturation.py
        ├── jaxincell
        │   ├── algorithms.py
        │   ├── boundary_conditions.py
        │   ├── constants.py
        │   ├── diagnostics.py
        │   ├── fields.py
        │   ├── particles.py
        │   ├── plot.py
        │   ├── simulation.py
        │   └── sources.py
        ├── main.py
        └── tests
            └── test_simulation.py
